// --- Declancher lors du chargement de la page
//
window.addEventListener('DOMContentLoaded', function() {

	// Recuperer l'element video de la webcam
	var webcam = document.getElementById('webcam');

	// Recuperer l'API getUserMedia selon le support du navigateur
	navigator.getUserMedia = (navigator.getUserMedia || 
							  navigator.webkitGetUserMedia || 
							  navigator.mozGetUserMedia || 
							  navigator.msGetUserMedia);
							  
	// Demander l'acces au dispositif webcam				  
	if(navigator.getUserMedia) {
		
		// Demander l'acces
		navigator.getUserMedia(
			// Indiquer ce que l'on desire recuperer
			{
				video:true,
				audio:true
			},
			// --- Fonction traitant le succes de connexion au webcam
			//
			function(stream){
				var url = window.URL || window.webkitURL;
				webcam.src = url ? url.createObjectURL(stream) : stream;
				webcam.play();
			},
			// --- Fonction traitant l'echec de connexion au webcam
			//
			function(erreur){
				alert('Something went wrong. (error code ' + erreur.code + ')');
				return;
			}
		);
	}
	else {
		alert('Sorry, the browser you are using doesn\'t support getUserMedia');
		return;
	}
	
	// --- Fonctions secondaires --- //
	// ----------------------------- //
	
	// --- Traitement de l'element video
	//
	var isStreaming = false,
    c = document.getElementById('c'),
    grey = document.getElementById('grey');
    con = c.getContext('2d');
    w = 600, 
    h = 420,
    greyscale = false; // Pour savoir si on souaite appliquer le traitement sur l'image video
	
	// Traiter la creation du flux du webcam
	//
	webcam.addEventListener('canplay', function(e) {
	   if (!isStreaming) {
		  // videoWidth isn't always set correctly in all browsers
		  if (webcam.videoWidth > 0) 
			h = webcam.videoHeight / (webcam.videoWidth / w);
		  c.setAttribute('width', w);
		  c.setAttribute('height', h);
		  // Reverse the canvas image
		  con.translate(w, 0);
		  con.scale(-1, 1);
		  isStreaming = true;
	   }
	}, 
	false);
	
	// Evenement de mise en marche de la video
	//
	webcam.addEventListener('play', function() {
	
	   // Copier une photo du flux du webcam vers le canvas traite toutes les 33 milisecondes
	   setInterval(function() {
	   
		  if (webcam.paused || webcam.ended) 
			return;
			
		  con.fillRect(0, 0, w, h);
		  con.drawImage(webcam, 0, 0, w, h);
		  
		  if (greyscale) 
			goingGrey();
			
	   }, 33);
	}, 
	false);
	
	// Evenement de clique sur le button (activer/desactiver le traitement sur la video)
	//
	grey.addEventListener('click', function() { greyscale = !greyscale; }, false);
 
	var goingGrey = function() {
	
		// Recuperer les donnees de l'image
		var imageData = con.getImageData(0, 0, w, h);
		var data = imageData.data;

		// Traiter l'image pour la modifier
		for (var i = 0; i < data.length; i += 4) {
		  var bright = 0.34 * data[i] + 0.5 * data[i + 1] + 0.16 * data[i + 2];
		  data[i] = bright;
		  data[i + 1] = bright;
		  data[i + 2] = bright;
		}

		con.putImageData(imageData, 0, 0);
	   
	}
	
});